@@ -16,8 +16,15 @@ class Recipe(Template):
         zope2location = options.get('zope2location')
         if not zope2location:
             raise UserError('zope2location is required for iw.recipe.mailer')
-        self.destination = os.path.join(options.get('zope2location'),
-                                        'etc', 'package-includes')
+
+        # The 'package-includes' directory is created only if there is one zcml
+        # file declared in the zope standalone or in all zeo clients.
+        includes_path = os.path.join(options.get('zope2location'),
+                                     'etc', 'package-includes')
+        if not os.path.exists(includes_path):
+            os.makedirs(includes_path)
+
+        self.destination = includes_path
 
         options.setdefault('name', 'iw.mailer')
         options.setdefault('host', 'localhost')
